@@ -22,6 +22,7 @@ class IRCOptionsForm(forms.Form):
     server = forms.CharField()
     port = forms.IntegerField()
     room = forms.CharField()
+    without_join = forms.BooleanField(required=False)
     nick = forms.CharField()
     password = forms.CharField(required=False)
     ssl = forms.BooleanField(required=False)
@@ -41,22 +42,24 @@ class IRCMessage(Plugin):
                    for k in ('server', 'port', 'nick', 'room')))
 
     def post_process(self, group, event, is_new, is_sample, **kwargs):
-        if not is_new:
+        if not is_new or not self.is_configured(event.project):
             return
-        server = self.get_option('server', event.project)
-        port = self.get_option('port', event.project)
-        nick = self.get_option('nick', event.project)
-        room = self.get_option('room', event.project)
-        if not room.startswith('#'):
-            room = '#%s' % room
-        password = self.get_option('password', event.project)
-        ssl = self.get_option('ssl', event.project)
         link = '%s/%s/group/%d/' % (settings.URL_PREFIX, group.project.slug,
                                     group.id)
         message = '[%s] %s (%s)' % (event.server_name, event.message, link)
-        self.send_payload(server, port, nick, password, room, ssl, message)
+        self.send_payload(event.project, message)
+
+    def send_payload(self, project, message):
+        server = self.get_option('server', project)
+        port = self.get_option('port', project)
+        nick = self.get_option('nick', project)
+        room = self.get_option('room', project)
+        without_join = self.get_option('without_join', project)
+        if not room.startswith('#'):
+            room = '#%s' % room
+        password = self.get_option('password', project)
+        ssl_c = self.get_option('ssl', project)
 
-    def send_payload(self, server, port, nick, password, room, ssl_c, message):
         irc = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         irc.connect((server, port))
         if ssl_c:
@@ -67,14 +70,16 @@ class IRCMessage(Plugin):
         ircsock.send("NICK %s\n" % nick)
         while 1:
             ircmsg = ircsock.recv(2048).strip('\n\r')
-            if re.findall(' 00[1-4] %s' % nick, ircmsg):
-                ircsock.send("JOIN %s\n" % room)
             pong = re.findall('^PING\s*:\s*(.*)$', ircmsg)
             if pong:
                 ircsock.send("PONG %s\n" % pong)
-            if re.findall(' 366 %s %s :' % (nick, room), ircmsg):
+            if re.findall(' 00[1-4] %s' % nick, ircmsg):
+                if not without_join:
+                    ircsock.send("JOIN %s\n" % room)
                 ircsock.send("PRIVMSG %s :%s\n" % (room, message))
-                ircsock.send("PART %s\n" % room)
+                if not without_join:
+                    ircsock.send("PART %s\n" % room)
                 break
-        irc.send("QUIT\n")
-        irc.close()
+        ircsock.recv(2048)
+        ircsock.send("QUIT\n")
+        ircsock.close()
